/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Thai (http://www.transifex.com/tine20/tine20/language/th/)\nLanguage: th\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "ImportExportDefinition, ImportExportDefinitions"
: [
  ""

]
, "Application, Applications"
: [
  "การประยุกต์ใช้"

]
, "User, Users"
: [
  "ผู้ใช้"

]
, "Groups"
: "กลุ่ม"

, "Roles"
: "หน้าที่"

, "Applications"
: "การประยุกต์ใช้"

, "Containers"
: "ที่จัดเก็บ"

, "Shared Tags"
: "ป้ายกำกับที่ใช้ร่วมกัน"

, "Customfields"
: ""

, "Computers"
: "คอมพิวเตอร์"

, "Access Log, Access Logs"
: [
  "บันทึกการใช้งาน"

]
, "Log"
: ""

, "Server Information"
: "ข้อมูลระบบ"

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Import Export Definitions"
: ""

, "Admin"
: "ผู้ดูแลระบบ"

, "Refresh"
: ""

, "Disabled"
: ""

, "Feature is disabled by configuration."
: ""

, "Default Addressbook for new contacts and groups"
: "สมุดรายชื่อหลักสำหรับการติดต่อและกลุ่มใหม่"

, "Computer Name"
: "ชื่อของคอมพิวเตอร์"

, "Config, Configs"
: [
  ""

]
, "Description"
: "การอธิบาย"

, "Name"
: "ชื่อ"

, "Label"
: "ป้าย"

, "Value"
: "ค่า"

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Group Name"
: "ชื่อกลุ่ม"

, "Visibility"
: "การมองเห็นได้"

, "Display in addressbook"
: "แสดงในสมุดรายชื่อ"

, "Hide from addressbook"
: "ซ่อนจากสมุดรายชื่อ"

, "Saved in Addressbook"
: "บันทึกแล้วในสมุดรายชื่อ"

, "E-mail"
: ""

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "สมาชิกของกลุ่ม"

, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Confirm"
: "ยืนยัน"

, "Do you really want to delete the selected tags?"
: "คุณแน่ใจว่าคุณต้องการลบป้ายกำกับที่เลือก?"

, "Deleting tag(s)..."
: "กำลังลบ ป้ายกำกับ(s)..."

, "Add Tag"
: "เพิ่มป้ายกำกับ"

, "Edit Tag"
: "แก้ไขป้ายกำกับ"

, "Delete Tag"
: "ลบป้ายกำกับ"

, "Search:"
: "ค้นหา:"

, "Displaying tags {0} - {1} of {2}"
: "กำกังแสดงป้ายกำกับ {0} - {1} จาก {2}"

, "No tags to display"
: "ไม่มีป้ายกำกับใด ๆ ให้แสดง"

, "ID"
: "รหัส"

, "Color"
: "สี"

, "Usage:&#160;"
: "การใช้:&#160;"

, "Do you really want to delete the selected roles?"
: "คุณแน่ใจว่าต้องการลบหน้าที่ที่เลือกไว้นี้?"

, "Deleting role(s)..."
: "กำลังลบ หน้าที่(s)..."

, "Failed"
: "ได้ล้มเหลว"

, "Some error occurred while trying to delete the role."
: "มีข้อผิดพลาดบางอย่างเกิดขึ้น ขณะที่พยายามลบหน้าที่"

, "Add Role"
: "เพิ่มหน้าที่"

, "Edit Role"
: "แก้ไขหน้าที่"

, "Delete Role"
: "ลบหน้าที่"

, "Displaying roles {0} - {1} of {2}"
: "กำลังแสดงหน้าที่ {0} - {1} จาก {2}"

, "No roles to display"
: "ไม่มีหน้าที่ใด ๆ ให้แสดง"

, "Container Name"
: "ชื่อที่จัดเก็บ"

, "Type"
: "ประเภท"

, "Container Order"
: ""

, "Container, Containers"
: [
  "ที่จัดเก็บ"

]
, "Model"
: "รุ่น"

, "personal"
: "ส่วนตัว"

, "shared"
: "ใช้ร่วมกัน"

, "Order"
: "คำสั่ง"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: "บันทึกสำหรับเจ้าของ"

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Do you really want to delete the selected groups?"
: "คุณแน่ใจว่าต้องการลบกลุ่มที่เลือกไว้นี้?"

, "Deleting group(s)..."
: "กำลังลบ กลุ่ม"

, "Some error occurred while trying to delete the group."
: "มีข้อผิดพลาดบางอย่างเกิดขึ้น ขณะที่พยายามลบกลุ่ม"

, "Add Group"
: "เพิ่มกลุ่ม"

, "Edit Group"
: "แก้ไขกลุ่ม"

, "Delete Group"
: "ลบกลุ่ม"

, "Displaying groups {0} - {1} of {2}"
: "กำลังแสดงกลุ่ม {0} - {1} จาก {2}"

, "No groups to display"
: "ไม่มีกลุ่มใด ๆ ให้แสดง"

, "Account only"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "IP Address"
: "หมายเลขไอพี"

, "Login Time"
: "เวลาเข้าใช้"

, "Logout Time"
: "เวลาเลิกใช้"

, "Client Type"
: "ประเภทลูกค้า"

, "Session ID"
: "รหัสเซสชัน"

, "Login Name"
: "ชื่อที่เข้าใช้"

, "Result"
: "ผลลัพธ์"

, "User Agent"
: ""

, "user blocked"
: "ผู้ใช้ถูกล็อก"

, "password expired"
: "รหัสผ่านหมดอายุแล้ว"

, "user disabled"
: "ผู้ใช้ปิดใช้งานแล้ว"

, "invalid password"
: "รหัสผ่านไม่ถูกต้อง"

, "ambiguous username"
: "ชื่อผู้ใช้คลุมเครือ"

, "user not found"
: "ผู้ใช้ไม่พบ"

, "failure"
: "ความล้มเหลว"

, "success"
: "ความสำเร็จ"

, "Customfield, Customfields"
: [
  ""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Errors"
: "ข้อผิดพลาด"

, "Please configure store for this field type"
: ""

, "Record Class"
: "บันทึก ชั้น"

, "Given record class not found"
: "ที่ให้บันทึกชั้นมานั้นหาไม่พบ"

, "Cancel"
: "ยกเลิก"

, "OK"
: "ตกลง"

, "Configure store"
: ""

, "Custom field definition"
: ""

, "Text"
: "ข้อความ"

, "Textarea"
: ""

, "Number"
: "ลำดับ"

, "Date"
: "วันที่"

, "DateTime"
: "วันเวลา"

, "Time"
: "เวลา"

, "Boolean"
: ""

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: "บันทึก"

, "Record List"
: ""

, "Length"
: "ความยาว"

, "Required"
: "ได้ต้องการ"

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Group, Groups"
: [
  "กลุ่ม"

]
, "Key"
: ""

, "Customfield already exists. Please choose another name."
: ""

, "Enable Account"
: "อนุญาตใช้บัญชี"

, "Disable Account"
: "เลิกบัญชี"

, "Reset Password"
: "ตั้งรหัสผ่านใหม่"

, "Status"
: "สถานะ"

, "Display name"
: "ชื่อที่ใช้"

, "Login name"
: "ชื่อที่เข้าใช้"

, "Last name"
: "นามสกุล"

, "First name"
: "ชื่อตัว"

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: "รหัสเปิด"

, "Last login at"
: "ลงชื่อเข้าใช้ครั้งล่าสุด เมื่อ"

, "Last login from"
: "ลงชื่อเข้าใช้ครั้งล่าสุด จาก"

, "Password Must Change"
: "รหัสผ่านต้องเปลี่ยน"

, "Password changed"
: "รหัสผ่านได้เปลี่ยนแล้ว"

, "Expires"
: "หมดอายุ"

, "Set new password"
: "ตั้งรหัสผ่านใหม่"

, "Please enter the new password:"
: "กรุณาใส่รหัสผ่านใหม่:"

, "Users"
: "ผู้ใช้"

, "Samba User, Samba Users"
: [
  "ผู้ใช้ Samba"

]
, "Email User, Email Users"
: [
  "ผู้ใช้อีเมล"

]
, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "รหัสผ่านไม่ตรง"

, "Passwords match!"
: "รหัสผ่านตรง!"

, "Primary group"
: "กลุ่มหลัก"

, "Unix"
: "ยูนิกซ์"

, "Home Directory"
: "โฮมไดเรคทอรี่"

, "Login Shell"
: ""

, "Windows"
: ""

, "Home Drive"
: ""

, "never logged in"
: "ไม่เคยได้เข้าใช้"

, "Home Path"
: ""

, "never logged off"
: "ไม่เคยเลิกใช้"

, "Profile Path"
: ""

, "Password Last Set"
: "รหัสผ่านที่ตั้งครั้งสุดท้าย"

, "never"
: "ไม่เลย"

, "Logon Script"
: ""

, "Password Can Change"
: "รหัสผ่านสามารถเปลี่ยน"

, "not set"
: "ยังไม่ได้กำหนด"

, "Kick Off Time"
: ""

, "Filesystem Quota"
: ""

, "Quota"
: "โควต้า"

, "no quota set"
: "ไม่ได้ตั้งโควต้า"

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: "ขนาดของกล่องจดหมายตอนนี้"

, "Sieve Quota"
: ""

, "Current Sieve size"
: "ขนาดของกรองปัจจุบัน"

, "Information"
: "ข้อมูล"

, "Last Login"
: "ลงบันทึกเข้าครั้งล่าสุด"

, "Forward Only"
: "ส่งต่อเท่านั้น"

, "E-mail Alias"
: ""

, "Add an alias address..."
: ""

, "This alias can be used for sending e-mails."
: ""

, "Domain not allowed"
: "โดเมนไม่ได้รับอนุญาต"

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Forwarding to self"
: "ส่งต่อให้ตัวเอง"

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Password confirmation"
: "การยืนยันรหัสผ่าน"

, "Repeat password"
: "ใส่รหัสผ่านอีกครั้ง"

, "Ok"
: "ตกลง"

, "Account"
: "บัญชี"

, "Password"
: "รหัสผ่าน"

, "Multi Factor Authentication Config"
: ""

, "enabled"
: "เปิดใช้งานแล้ว"

, "disabled"
: "ปิดใช้งานแล้ว"

, "expired"
: "หมดอายุแล้ว"

, "blocked"
: "ถูกล็อก"

, "Invalid Status"
: "สถานะใช้ไม่ได้"

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: "สถานะ ถูกล็อก จะใช้ต่อเมื่อผู้ใช้พยายามลงชื่อเข้าใช้ด้วยรหัสผ่านที่ผิดบ่อย ๆ ณ ที่นี่ไม่สามารถตั้งค่าสถานะนี้ได้"

, "don't know"
: "ไม่ทราบ"

, "Password set"
: "ตั้งรหัสผ่าน"

, "User groups"
: "กลุ่มผู้ใช้"

, "User roles"
: ""

, "Fileserver"
: "ตัวจัดเก็บไฟล์"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "Computer, Computers"
: [
  "คอมพิวเตอร์"

]
, "Please wait"
: "กรุณารอ"

, "Updating Memberships"
: "กำลังปรับปรุงการเป็นสมาชิก"

, "Could not save role."
: "ไม่สามารถจัดเก็บหน้าที่ได้"

, "Please fix the errors noted."
: "กรุณาแก้ไขข้อผิดพลาดที่ได้บันทึกไว้"

, "Deleting role..."
: "กำลังลบ หน้าที่..."

, "Rights"
: "สิทธิ์"

, "Members"
: "สมาชิก"

, "Role Name"
: "ชื่อหน้าที่"

, "Transferring {0}..."
: "กำลังโอนย้าย {0}..."

, "Role"
: "หน้าที่"

, "Add New Role"
: "เพิ่มหน้าที่ใหม่"

, "Edit Role \"{0}\""
: "แก้ไขหน้าที่ \"{0}\""

, "Configs"
: ""

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Updating Tag"
: "กำลังปรับปรุงป้ายกำกับ"

, "Could not save tag ({0})"
: "ไม่สามารถจัดเก็บป้ายกำกับ ({0}) ได้"

, "Allowed Contexts"
: "เนื้อหาที่อนุญาต"

, "Context"
: "เนื้อหา"

, "Account Rights"
: "สิทธิ์เกี่ยวกับบัญชี"

, "View"
: "ดู"

, "Use"
: "ใช้"

, "Tag Name"
: "ชื่อป้ายกำกับ"

, "Tag"
: "ป้ายกำกับ"

, "Add New Tag"
: "เพิ่มป้ายกำกับใหม่"

, "Edit Tag \"{0}\""
: "แก้ไขป้ายกำกับ \"{0}\""

, "Enable Application"
: "อนุญาตให้ใช้แอพลิเคชั่น"

, "Disable Application"
: "ยกเลิกการใช้แอพลิเคชั่น"

, "Settings"
: "ค่าติดตั้ง"

, "{0} Settings"
: "ค่าติดตั้ง {0}"

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "แสดงการใช้ {0} - {1} จาก {2}"

, "No applications to display"
: "ไม่มีการใช้ใด ๆ ให้แสดง"

, "Version"
: "ภาค"

, "Default password must change for new user settings"
: ""

, "Default IMAP user settings"
: "ค่าตั้งตั้งของผู้ใช้ IMAP หลัก "

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: "เปลี่ยนแปลงตู้ใส่ของของคุณแล้ว"

, "Your container has been changed by %1$s %2$sNote: %3$s"
: "มีการเปลี่ยนแปลงตู้ใส่ของของคุณ โดย %1$s %2$sหมายเหตุ: %3$s"

, "Password is needed for system account creation"
: ""

, "Notifications"
: ""

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "Manage import and export definitions"
: ""

, "Add and edit import and export definitions"
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""

, "view ImportExportDefinitions"
: ""







































, "ImportExportDefinition"
: ""

, "Application"
: "การประยุกต์ใช้"

, "User"
: "ผู้ใช้"

, "Access Log"
: "บันทึกการใช้งาน"

, "Config"
: ""

, "Container"
: "ที่จัดเก็บ"

, "Customfield"
: ""

, "Group"
: "กลุ่ม"

, "Samba User"
: "ผู้ใช้ Samba"

, "Email User"
: "ผู้ใช้อีเมล"

, "Computer"
: "คอมพิวเตอร์"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
